itkwasm.mesh - itkwasm python documentation
Description: Module Contents: Classes:,, MeshType,,, Mesh,,,,, API:

Hide navigation sidebar
Hide table of contents sidebar
Back to top
Edit this page
Toggle table of contents sidebar

# `itkwasm.mesh`

## Module Contents

### Classes

`MeshType` |
`Mesh` |

### API

class itkwasm.mesh.MeshType
  dimension: int

    3

  pointComponentType: Union[itkwasm.int_types.IntTypes, itkwasm.float_types.FloatTypes]

    None

  pointPixelComponentType: Union[itkwasm.int_types.IntTypes, itkwasm.float_types.FloatTypes]

    None

  pointPixelType: itkwasm.pixel_types.PixelTypes

    None

  pointPixelComponents: int

    1

  cellComponentType: Union[itkwasm.int_types.IntTypes, itkwasm.float_types.FloatTypes]

    None

  cellPixelComponentType: Union[itkwasm.int_types.IntTypes, itkwasm.float_types.FloatTypes]

    None

  cellPixelType: itkwasm.pixel_types.PixelTypes

    None

  cellPixelComponents: int

    1

class itkwasm.mesh.Mesh
  meshType: Union[itkwasm.mesh.MeshType, Dict]

    None

  name: str

    ‘Mesh’

  numberOfPoints: int

    0

  points: Optional[numpy.typing.ArrayLike]

    None

  numberOfPointPixels: int

    0

  pointData: Optional[numpy.typing.ArrayLike]

    None

  numberOfCells: int

    0

  cells: Optional[numpy.typing.ArrayLike]

    None

  cellBufferSize: int

    0

  numberOfCellPixels: int

    0

  cellData: Optional[numpy.typing.ArrayLike]

    None

  __post_init__()